Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(507)

Unified Diff: ash/common/shelf/shelf_button.h

Issue 2727073002: Preliminary cleanup of ShelfButton activity/status indicator. (Closed)
Patch Set: rebase Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | ash/common/shelf/shelf_button.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/common/shelf/shelf_button.h
diff --git a/ash/common/shelf/shelf_button.h b/ash/common/shelf/shelf_button.h
index 8e2bc3d4910ffb7958642bc00bce02cafeba6a38..4f828ea182e82010bffef022d7c3c08088e1a6b7 100644
--- a/ash/common/shelf/shelf_button.h
+++ b/ash/common/shelf/shelf_button.h
@@ -94,15 +94,12 @@ class ASH_EXPORT ShelfButton : public views::CustomButton {
void SetShadowedImage(const gfx::ImageSkia& bitmap);
private:
- class BarView;
+ class AppStatusIndicatorView;
// Updates the parts of the button to reflect the current |state_| and
// alignment. This may add or remove views, layout and paint.
void UpdateState();
- // Updates the status bar (bitmap, orientation, visibility).
- void UpdateBar();
-
InkDropButtonListener* listener_;
// The shelf view hosting this button.
@@ -111,8 +108,9 @@ class ASH_EXPORT ShelfButton : public views::CustomButton {
// The icon part of a button can be animated independently of the rest.
views::ImageView* icon_view_;
- // Draws a bar underneath the image to represent the state of the application.
- BarView* bar_;
+ // Draws an indicator underneath the image to represent the state of the
+ // application.
+ AppStatusIndicatorView* indicator_;
// The current application state, a bitfield of State enum values.
int state_;
« no previous file with comments | « no previous file | ash/common/shelf/shelf_button.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698